/* GCC */

#include <iostream>
#include <fstream>
#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>
#include <cmath>
#include <utility>
#include <stdint.h>
#include <inttypes.h>
using namespace std;

int gcd(int a, int b)
{
    a = abs(a);
    b = abs(b);
    
    while (a != 0 && b != 0) {
        if (a > b)
            a %= b;
        else
            b %= a;
    }
    
    return ((a+b != 0)?(a+b):1);
}

struct Fract
{
    int den, num;
    
    Fract() : den(1), num(0) {}
    Fract(int n) : den(1), num(n) {}
    Fract(int n, int d) 
    {
        int g = gcd(n, d);
        n /= g;
        d /= g;
        
        if (n < 0 && d < 0) {
            n *= -1;
            d *= -1;
        }
        den = d;
        num = n;
    }
    Fract operator+(const Fract& l) const
    {
        return Fract(num*l.den + den*l.num, den*l.den);
    }
    Fract operator-(const Fract& l) const
    {
        return Fract(num*l.den - den*l.num, den*l.den);
    }
    Fract operator*(const Fract& l) const
    {
        return Fract(num*l.num, den*l.den);
    }
    Fract operator-() const
    {
        return Fract(-num, den);
    }
    Fract operator/(const Fract& l) const
    {
        return Fract(num*l.den, den*l.num);
    }
    bool operator==(const Fract& l) const
    {
        return (*this-l).num == 0;
    }
    bool operator<(const Fract& l) const
    {
        return (*this-l).num < 0;
    }
};

ostream& operator<<(ostream& o, Fract p)
{
    if (p.den < 0) {
        p.den *= -1;
        p.num *= -1;
    }
    o << p.num;
    if (p.den != 1) 
        o << "/" << p.den;
    return o;
}


Fract abs(Fract x) 
{
    if (x.num < 0)
        x.num *= -1;
    if (x.den < 0)
        x.den *= -1;
    
    return x;
}

Fract sqrt(Fract x)
{
    x = abs(x);
    return Fract(sqrt(x.num), sqrt(x.den));
}

struct Point
{
    Fract x, y;
    Point(Fract x, Fract y) : x(x), y(y) {}
    bool operator==(const Point& l) const
    {
        return x == l.x && y == l.y;
    }
};

ostream& operator<<(ostream& o, const Point& p)
{
    o << p.x << " " << p.y;
    return o;
}


struct Line
{
    Fract a, b, c;
    Line(Fract x1, Fract y1, Fract x2, Fract y2)
    {
        Fract l = x2-x1;
        Fract m = y2-y1;
        a = m;
        b = -l;
        c = l*y1-m*x1;
    }
    void intersect(const Line& l, vector<Point>& s) const
    {
        Fract d0 = det(a, b, l.a, l.b);
        Fract dx = det(-c, b, -l.c, l.b);
        Fract dy = det(a, -c, l.a, -l.c);
        
        if (d0.num != 0 && find(s.begin(), s.end(), Point(dx/d0, dy/d0)) == s.end()) {
            s.push_back(Point(dx/d0, dy/d0));
        }
    }
    
    Fract distance(const Line& l) const
    {
        Fract d1 = ((c)/ (sqrt(a*a+b*b)));
        Fract d2 = ((l.c) / (sqrt(l.a*l.a + l.b*l.b)));
        
        return abs(d1-d2);
    }
    
    Fract distance(const Point& p) const
    {
        Fract mod = abs(a*p.x + b*p.y+c);
        Fract mod2 = abs(a*a+b*b);
        
        return (mod) / (sqrt(mod2));
    }
    static Fract det(Fract a1, Fract a2, Fract b1, Fract b2) {return a1*b2-a2*b1;}
};

int lcd(int a, int b) {return a/gcd(a,b)*b;}

ostream& operator<<(ostream& o, Line l)
{
    int g = lcd(l.a.den, lcd(l.b.den, l.c.den));
    int a = l.a.num * g;
    int b = l.b.num*g;
    int c = l.c.num*g;
    g = gcd(a, gcd(b, c));
    if (a < 0 || (a == 0 && b < 0))
    {
        a *= -1;
        b *= -1;
        c *= -1;
    }
    o << a / g << " " << b/g << " " << c/g;
    return o;
}

int main()
{
    ifstream fin("motel.in");
    ofstream fout("motel.out");
    
    int n;
    vector<Line> ls;
    fin >> n;
    
    for (int i = 0; i < n; ++i) {
        int x1,y1,x2,y2;
        fin >> x1 >> y1 >> x2 >> y2;
        ls.push_back(Line(x1, y1, x2, y2));
    }
    
    vector<Point> point;
    
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < n; ++j) {
            ls[i].intersect(ls[j], point);
        }
    }
    
    vector<Point> pts(point.begin(), point.end());
    
    if (!pts.empty()) {
        vector<pair<Fract, int> > dist;
         
        for (int i = 0; i < pts.size(); ++i) {
            Fract sum = 0;
            
            for (int j = 0;j < ls.size(); ++j) 
                sum = sum + ls[j].distance(pts[i]);
            dist.push_back(make_pair(sum, i));
        }
        sort(dist.begin(), dist.end());
        
        int i = 1;
        while (dist[i].first == dist[0].first)
            ++i;
        --i;
        fout << dist[0].first << "\n";
        fout << i + 1 << "\n";
        
        for (int j = 0; j <= i; ++j) {
            fout << point[dist[j].second] << "\n";
        }
        
    } 
    else 
    {
        vector<pair<Fract, int> > dist;
        
        for (int i = 0; i < ls.size(); ++i) {
            Fract sum = 0;
            
            for (int j = 0; j < ls.size(); ++j)
                sum = sum + ls[i].distance(ls[j]);
            dist.push_back(make_pair(sum, i));
        }
        
        sort(dist.begin(), dist.end());
        if (dist[0].first == dist[1].first) {
            fout << dist[0].first << "\n"; 
            fout << "-2\n" << ls[dist[0].second] << "\n" << ls[dist[1].second] << "\n";
        } 
        else{
            fout << dist[0].first << "\n";
            fout << "-1\n"<< ls[dist[0].second] << "\n";
        }
    }
    
    return 0;
}
